/*
 * Appcelerator Sync Server Example Application
 *
 * This application demonstrates how to use the Sync Server Client module to
 * synchronize MS Dynamics CRM data with the Sync Server.
 *
 * Before running this application, you must have an active Sync Server instance
 * with the msDynamicsCrm1.0 adapter configured and running.
 *
 * The Sync Server Client requires a `syncConfig.json` file with the appropriate
 * configuration options defined. The `syncConfig.json` file provided with this
 * example specifies a default `appId` and `serverAddress`. You must change the values
 * of these properties to match your Sync Server's configuration. You can either change
 * these properties in the `syncConfig.json` file OR set these properties on the
 * connector when you call `createSyncConnector`.
 *
 * The Sync Server requires a user and password for authentication. You must
 * update the credentials below before authenticating with the Sync Server
 *
 * To run the example:
 *   1. Install the appcelerator.syncserver.client module (if not already installed)
 *   2. Create a new Titanium application
 *   3. Add the appcelerator.syncserver.client module to your application's tiapp.xml file
 *   4. Copy the app.js and syncConfig.json file from the example folder into your new Titanium application
 *   5. Update the appId and serverAddress properties in the syncConfig.json file
 *   6. Update the user and password credentials in the app.js file
 *   7. Run the application
 *   8. Click on 'Sync' to pull the current records from the Sync Server
 *
 * Progress messages are output to the console
 */

var credentials = {
	user: 'user@company.com',
	password: 'password'
}

// Create the UI for the application
createUI();

// Load the sync client module
var syncClient = require('appcelerator.syncserver.client');

// Create a connector for the msDynamicsCrm1.0 connector
var connector = syncClient.createSyncConnector({
	name: 'msDynamicsCrm1.0'
});

// Create the database -- it must exist prior to synchronization
createDatabase();

//=====================================================================

function createUI() {
	var win = Ti.UI.createWindow({
		backgroundColor: 'white',
		layout: 'vertical'
	});

	var btnSync = Ti.UI.createButton({ title: 'Sync', top: 4,	left: 4, right: 4 });

	btnSync.addEventListener('click', synchronize);

	win.add(btnSync);

	win.open();
}

function createDatabase() {
	// Create the application's database -- make sure every non-picklist table has the 'modifiedon' field
	var db = Ti.Database.open(connector.databaseName);
	db.execute('CREATE TABLE IF NOT EXISTS contact (contactid TEXT PRIMARY KEY, fullname TEXT, firstname TEXT, lastname TEXT, modifiedon TEXT)');
	// For the example application, delete all existing rows from the tables so we start
	// with a clean slate every time the application is run.
	db.execute('DELETE FROM contact');
	db.close();
}

function formatJSON(evt) {
	return JSON.stringify(evt, function(key, value) {
		if(key === 'source' || key === 'type') {
			return undefined;
		} else {
			return value;
		}
	}, 2);
}

//=====================================================================

function synchronize() {
	connector.sync({
		user: credentials.user,
		password: credentials.password,
		success: function (e) {
			Ti.API.info("Successfully synchronized: " + formatJSON(e));
		},
		error: function (e) {
			Ti.API.error("Error during sync: " + formatJSON(e));
		},
		progress: function(e) {
			Ti.API.info("Sync Progress: " + formatJSON(e));
		}
	});
}
	



